@@ -106,6 +106,33 @@ eel_gdk_pixbuf_load (const char *uri)
 
 GdkPixbuf *
 eel_gdk_pixbuf_load_from_stream (GInputStream  *stream)
+{
+	return eel_gdk_pixbuf_load_from_stream_at_size (stream, -1);
+}
+
+static void
+pixbuf_loader_size_prepared (GdkPixbufLoader *loader,
+			     int              width,
+			     int              height,
+			     gpointer         desired_size_ptr)
+{
+	int size, desired_size;
+	float scale;
+
+	size = MAX (width, height);
+	desired_size = GPOINTER_TO_INT (desired_size_ptr);
+
+	if (size != desired_size) {
+		scale = desired_size / size;
+		gdk_pixbuf_loader_set_size (loader,
+					    floor (scale * width + 0.5),
+					    floor (scale * height + 0.5));
+	}
+}
+
+GdkPixbuf *
+eel_gdk_pixbuf_load_from_stream_at_size (GInputStream  *stream,
+					 int            size)
 {
 	char buffer[LOAD_BUFFER_SIZE];
 	gssize bytes_read;
@@ -118,6 +145,13 @@ eel_gdk_pixbuf_load_from_stream (GInputStream  *stream)
 
 	got_eos = FALSE;
 	loader = gdk_pixbuf_loader_new ();
+
+	if (size > 0) {
+		g_signal_connect (loader, "size-prepared",
+				  G_CALLBACK (pixbuf_loader_size_prepared),
+				  GINT_TO_POINTER (size));
+	}
+
 	while (1) {
 		bytes_read = g_input_stream_read (stream, buffer, sizeof (buffer),
 						  NULL, NULL);
