@@ -30,16 +30,16 @@
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkdrawable.h>
 #include <gdk/gdkrgb.h>
-#include <libgnomevfs/gnome-vfs-result.h>
+#include <gio/gio.h>
 
 #define EEL_STANDARD_ALPHA_THRESHHOLD 128
 #define EEL_OPACITY_FULLY_TRANSPARENT 0
 #define EEL_OPACITY_FULLY_OPAQUE      255
 
-extern const ArtIRect eel_gdk_pixbuf_whole_pixbuf;
+extern const EelIRect eel_gdk_pixbuf_whole_pixbuf;
 
 typedef struct EelPixbufLoadHandle EelPixbufLoadHandle;
-typedef void (* EelPixbufLoadCallback) (GnomeVFSResult  error,
+typedef void (* EelPixbufLoadCallback) (GError         *error,
 					GdkPixbuf      *pixbuf,
 					gpointer        callback_data);
 
@@ -51,6 +51,9 @@ void                 eel_gdk_pixbuf_list_free                 (GList
 
 /* Loading a GdkPixbuf with a URI. */
 GdkPixbuf *          eel_gdk_pixbuf_load                      (const char            *uri);
+GdkPixbuf *          eel_gdk_pixbuf_load_from_stream          (GInputStream          *stream);
+GdkPixbuf *          eel_gdk_pixbuf_load_from_stream_at_size  (GInputStream          *stream,
+							       int                    size);
 
 
 /* Same thing async. */
@@ -71,11 +74,20 @@ double               eel_gdk_scale_to_fit_factor              (int
 							       int                    max_height,
 							       int                   *scaled_width,
 							       int                   *scaled_height);
+GdkPixbuf *          eel_gdk_pixbuf_scale_to_min              (GdkPixbuf             *pixbuf,
+							       int                    min_width,
+							       int                    min_height);
+double              eel_gdk_scale_to_min_factor               (int                   width,
+                                                               int                   height,
+							       int                   min_width,
+							       int                   min_height,
+							       int                   *scaled_width,
+							       int                   *scaled_height);
 
 /* return average color values for each component (argb) */
 guint32              eel_gdk_pixbuf_average_value             (GdkPixbuf             *pixbuf);
 void                 eel_gdk_pixbuf_fill_rectangle_with_color (GdkPixbuf             *pixbuf,
-							       ArtIRect               area,
+							       EelIRect               area,
 							       guint32                color);
 
 
@@ -92,7 +104,7 @@ void                 eel_gdk_pixbuf_draw_to_drawable          (const GdkPixbuf
 							       GdkGC                 *gc,
 							       int                    source_x,
 							       int                    source_y,
-							       ArtIRect               destination_area,
+							       EelIRect               destination_area,
 							       GdkRgbDither           dither,
 							       GdkPixbufAlphaMode     alpha_compositing_mode,
 							       int                    alpha_threshold);
@@ -102,7 +114,7 @@ void                 eel_gdk_pixbuf_draw_to_pixbuf            (const GdkPixbuf
 							       GdkPixbuf             *destination_pixbuf,
 							       int                    source_x,
 							       int                    source_y,
-							       ArtIRect               destination_area);
+							       EelIRect               destination_area);
 
 
 /* Composite one pixbuf over another with the given opacity */
@@ -110,43 +122,19 @@ void                 eel_gdk_pixbuf_draw_to_pixbuf_alpha      (const GdkPixbuf
 							       GdkPixbuf             *destination_pixbuf,
 							       int                    source_x,
 							       int                    source_y,
-							       ArtIRect               destination_area,
+							       EelIRect               destination_area,
 							       int                    opacity,
 							       GdkInterpType          interpolation_mode);
 
 
-/* Fill an area of a pixbuf with a tile. */
-void                 eel_gdk_pixbuf_draw_to_pixbuf_tiled      (const GdkPixbuf       *pixbuf,
-							       GdkPixbuf             *destination_pixbuf,
-							       ArtIRect               destination_area,
-							       int                    tile_width,
-							       int                    tile_height,
-							       int                    tile_origin_x,
-							       int                    tile_origin_y,
-							       int                    opacity,
-							       GdkInterpType          interpolation_mode);
-
-/* Fill an area of a drawable with a tile. */
-void                 eel_gdk_pixbuf_draw_to_drawable_tiled    (const GdkPixbuf       *pixbuf,
-							       GdkDrawable           *drawable,
-							       GdkGC                 *gc,
-							       ArtIRect               destination_area,
-							       int                    tile_width,
-							       int                    tile_height,
-							       int                    tile_origin_x,
-							       int                    tile_origin_y,
-							       GdkRgbDither           dither,
-							       GdkPixbufAlphaMode     alpha_compositing_mode,
-							       int                    alpha_threshold);
-
 /* Create a pixbuf from a sub area of another pixbuf */
 GdkPixbuf *          eel_gdk_pixbuf_new_from_pixbuf_sub_area  (GdkPixbuf             *pixbuf,
-							       ArtIRect               area);
+							       EelIRect               area);
 /* Create a pixbuf from an existing buffer. */
 GdkPixbuf *          eel_gdk_pixbuf_new_from_existing_buffer  (guchar                *buffer,
 							       int                    buffer_rowstride,
 							       gboolean               buffer_has_alpha,
-							       ArtIRect               area);
+							       EelIRect               area);
 
 /* Determine whether a pixbuf is valid or not */
 gboolean             eel_gdk_pixbuf_is_valid                  (const GdkPixbuf       *pixbuf);
@@ -155,22 +143,10 @@ gboolean             eel_gdk_pixbuf_is_valid                  (const GdkPixbuf
 EelDimensions        eel_gdk_pixbuf_get_dimensions            (const GdkPixbuf       *pixbuf);
 
 /* Return the intersection of the pixbuf with the given rectangle. */
-ArtIRect             eel_gdk_pixbuf_intersect                 (const GdkPixbuf       *pixbuf,
+EelIRect             eel_gdk_pixbuf_intersect                 (const GdkPixbuf       *pixbuf,
 							       int                    pixbuf_x,
 							       int                    pixbuf_y,
-							       ArtIRect               rectangle);
-
-/* Text drawing. */
-void                 eel_gdk_pixbuf_draw_layout               (GdkPixbuf             *pixbuf,
-							       int                    x,
-							       int                    y,
-							       guint32                color,
-							       PangoLayout           *layout);
-
-void                 eel_gdk_pixbuf_draw_layout_clipped       (GdkPixbuf             *pixbuf,
-							       ArtIRect               region,
-							       guint32                color,
-							       PangoLayout           *layout);
+							       EelIRect               rectangle);
 
 /* Scales large pixbufs down fast */
 GdkPixbuf *          eel_gdk_pixbuf_scale_down                (GdkPixbuf *pixbuf,
